/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.glib.GObject;
import org.gnu.glib.Handle;

/**
 *
 */
public class Keymap extends GObject 
{
    public Keymap() {
        super( getType() );
    }

    /**
     * Retrieve the runtime type used by the GLib library.
     */
    public static org.gnu.glib.Type getType() {
        return new org.gnu.glib.Type(gdk_keymap_get_type());
    }

    /****************************************
     * BEGINNING OF JNI CODE
     ****************************************/
    native static final protected int gdk_keymap_get_type ();
    native static final protected Handle gdk_keymap_get_default ();
    native static final protected int gdk_keymap_lookup_key (Handle keymap, Handle key);
    native static final protected boolean gdk_keymap_get_entries_for_keyval (Handle keymap, int 
        keyval, Handle [] keys);
    native static final protected boolean gdk_keymap_get_entries_for_keycode (Handle keymap, int 
        hardwareKeycode, Handle[] keys, int [] keyvals);
    native static final protected int gdk_keymap_get_direction (Handle keymap);
    /****************************************
     * END OF JNI CODE
     ****************************************/
}

